..
   Template for the html class rendering

   Modified from
   https://github.com/sphinx-doc/sphinx/tree/master/sphinx/ext/autosummary/templates/autosummary/class.rst

lbfgsb.bfgsmats.LBFGSB\_MATRICES
================================

.. currentmodule:: lbfgsb.bfgsmats

.. autoclass:: LBFGSB_MATRICES
   :members:
   :private-members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__
   

   .. rubric:: Methods definition